var NAVTREE =
[
  [ "WiredTiger", "index.html", [
    [ "Reference Guide", "index.html", "index" ],
    [ "Modules", "modules.html", "modules" ],
    [ "Class List", "annotated.html", "annotated" ],
    [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
    [ "Class Members", "functions.html", [
      [ "All", "functions.html", "functions_dup" ],
      [ "Functions", "functions_func.html", "functions_func" ],
      [ "Variables", "functions_vars.html", null ],
      [ "Enumerator", "functions_eval.html", null ]
    ] ],
    [ "Examples", "examples.html", "examples" ],
    [ "Community", "community.html", null ],
    [ "License", "license.html", null ]
  ] ]
];

var NAVTREEINDEX =
[
".html",
"classcom_1_1wiredtiger_1_1db_1_1_pack_input_stream.html",
"durability.html",
"group__wt.html#ga33ac35e64c48896c09905f7b5e7068d4",
"group__wt.html#ga9f2f8149523b1e6e4f64100ef198e050",
"license.html#license_distribution",
"struct_w_t___f_i_l_e___h_a_n_d_l_e.html#a350e1db2cd51c8c2479b03beae9af90f"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';